@@ -1,8 +1,8 @@
 # This method takes a {framework.db.cred}, and normalizes it
 # to the string format JTR is expecting.
 #
-# @param [credClass] a credential from framework.db
-# @return [String] the hash in jtr format or nil on no mach
+# @param cred [credClass] A credential from framework.db
+# @return [String] The hash in jtr format or nil on no match.
 def hash_to_jtr(cred)
   case cred.private.type
   when 'Metasploit::Credential::NTLMHash'
@@ -53,8 +53,8 @@ def hash_to_jtr(cred)
     when /md5|des|bsdi|crypt|bf|sha256|sha512|xsha512/
       # md5(crypt), des(crypt), b(crypt), sha256(crypt), sha512(crypt), xsha512
       return "#{cred.public.username}:#{cred.private.data}:::::#{cred.id}:"
-    when /netntlm(v2)?/
-      return cred.private.data
+    when /netntlm/
+      return "#{cred.private.data}::::::#{cred.id}:"
     when /qnx/
       # https://moar.so/blog/qnx-password-hash-formats.html
       hash = cred.private.data.end_with?(':0:0') ? cred.private.data : "#{cred.private.data}:0:0"
