@@ -153,7 +153,8 @@ module Exploit
       raise $!
     rescue ::Msf::OptionValidateError => e
       exploit.error = e
-      ::Msf::Ui::Formatter::OptionValidateError.print_error(oexploit, e)
+      ::Msf::Ui::Formatter::OptionValidateError.print_error(exploit, e)
+      return false
     rescue ::Exception => e
       exploit.error = e
       exploit.print_error("Exploit failed: #{e}")
@@ -248,4 +249,3 @@ end
 
 end
 end
-
