@@ -151,6 +151,8 @@ module Exploit::Remote::HttpClient
     client_username = opts['username'] || datastore['HttpUsername'] || ''
     client_password = opts['password'] || datastore['HttpPassword'] || ''
 
+    http_logger_subscriber = Rex::Proto::Http::HttpLoggerSubscriber.new(logger: self)
+    
     nclient = Rex::Proto::Http::Client.new(
       opts['rhost'] || rhost,
       (opts['rport'] || rport).to_i,
@@ -163,7 +165,8 @@ module Exploit::Remote::HttpClient
       proxies,
       client_username,
       client_password,
-      comm: opts['comm']
+      comm: opts['comm'],
+      subscriber: http_logger_subscriber
     )
 
 
@@ -369,34 +372,8 @@ module Exploit::Remote::HttpClient
     c = opts['client'] || connect(opts)
     r = opts[:cgi] ? c.request_cgi(opts) : c.request_raw(opts)
 
-    if datastore['HttpTrace']
-      request_color, response_color =
-        (datastore['HttpTraceColors'] || '').split('/').map { |color| "%bld%#{color}" }
-
-      request = r.to_s(headers_only: datastore['HttpTraceHeaders'])
-
-      print_line('#' * 20)
-      print_line('# Request:')
-      print_line('#' * 20)
-      print_line("%clr#{request_color}#{request}%clr")
-    end
-
     res = c.send_recv(r, actual_timeout)
 
-    if datastore['HttpTrace']
-      print_line('#' * 20)
-      print_line('# Response:')
-      print_line('#' * 20)
-
-      if res
-        response = res.to_terminal_output(headers_only: datastore['HttpTraceHeadersOnly'])
-
-        print_line("%clr#{response_color}#{response}%clr")
-      else
-        print_line('No response received')
-      end
-    end
-
     disconnect(c) if disconnect
 
     res
@@ -723,7 +700,6 @@ module Exploit::Remote::HttpClient
     datastore['Proxies']
   end
 
-
   #
   # Lookup HTTP fingerprints from the database that match the current
   # destination host and port. This method falls back to using the old
