@@ -230,8 +230,8 @@ module Exploit::Remote::RDP
       [self.rdp_user_id, chan_id].pack('S>S>'), # MCS send data request structure, choice 25
       "\x70", # Wut (security header)
       per_data(
-        [data_length].pack('<L'),
-        [flags].pack('<L'),
+        [data_length].pack('L<'),
+        [flags].pack('L<'),
         data
       )
     ].join('')
@@ -584,7 +584,7 @@ module Exploit::Remote::RDP
 
     sha1 << mac_salt_key
     sha1 << pad1
-    sha1 << [data_content.length].pack('<L')
+    sha1 << [data_content.length].pack('L<')
     sha1 << data_content
 
     md5 << mac_salt_key
@@ -1247,10 +1247,10 @@ protected
     flags: RDPConstants::REDIRECTION_SUPPORTED | RDPConstants::REDIRECTION_VERSION3,
     session_id: 0
   )
-    body = [flags, session_id].pack('<L<L')
+    body = [flags, session_id].pack('L<L<')
 
     result = [
-      [0xc004, body.length + 4].pack('<S<S'),
+      [0xc004, body.length + 4].pack('S<S<'),
       body
     ].join('')
 
@@ -1261,10 +1261,10 @@ protected
     encryption_methods: RDPConstants::ENCRYPTION_40BIT | RDPConstants::ENCRYPTION_128BIT,
     ext_encryption_methods: 0
   )
-    body = [encryption_methods, ext_encryption_methods].pack('<L<L')
+    body = [encryption_methods, ext_encryption_methods].pack('L<L<')
 
     result = [
-      [0xc002, body.length + 4].pack('<S<S'),
+      [0xc002, body.length + 4].pack('S<S<'),
       body
     ].join('')
 
@@ -1273,7 +1273,7 @@ protected
 
   def cs_network_data(channels)
     chan_data = channels.map{ |c|
-      [c[0].encode('ASCII')].pack('a8*') + [c[1]].pack('L')
+      [c[0].encode('ASCII')].pack('a8') + [c[1]].pack('L')
     }.join('')
 
     body = [
@@ -1282,13 +1282,14 @@ protected
     ].join('')
 
     result = [
-      [0xc003, body.length + 4].pack('<S<S'),
+      [0xc003, body.length + 4].pack('S<S<'),
       body
     ].join('')
 
     result
   end
 
+  # https://learn.microsoft.com/en-us/openspecs/windows_protocols/ms-rdpbcgr/00f1da4a-ee9c-421a-852f-c19f92343d73
   def cs_core_data(
     version: 0x80004,
     width: 800,
@@ -1309,18 +1310,18 @@ protected
     client_dig_product_id = Rex::Text.to_unicode(client_dig_product_id[0..32], 'utf-16le')
 
     body = [
-      [version, width, height].pack('<L<S<S'),
+      [version, width, height].pack('L<S<S<'),
       "\x01\xca", # colour depth (8BPP)
       "\x03\xaa", # SASSequence
-      [keyboard, client_build, client_name, keyboard_type].pack('<L<La32*'),
-      [keyboard_type, keyboard_subtype, keyboard_func_key].pack('<L<L<L'),
+      [keyboard, client_build, client_name].pack('L<L<a32'),
+      [keyboard_type, keyboard_subtype, keyboard_func_key].pack('L<L<L<'),
       "\x00" * 64, # imeFileName
       "\x01\xca", # postBeta2ColorDepth (8BPP)
-      [client_product_id, serial_num].pack('<S<L'),
+      [client_product_id, serial_num].pack('S<L<'),
       "\x18\x00", # highColorDepth: 24 bpp
       "\x07\x00", # supportedColorDepths: flag (24 bpp | 16 bpp | 15 bpp )
       "\x01\x00", # earlyCapabilityFlags: 1 (RNS_UD_CS_SUPPORT_ERRINFO_PDU)
-      [client_dig_product_id].pack('a64*'),
+      [client_dig_product_id].pack('a64'),
       "\x00", # connectionType: 0
       "\x00", # pad1octet
       # serverSelectedProtocol - After negotiating TLS or CredSSP this value must
@@ -1330,7 +1331,7 @@ protected
     ].join('')
 
     result = [
-      [0xc001, body.length + 4].pack('<S<S'),
+      [0xc001, body.length + 4].pack('S<S<'),
       body
     ].join('')
 
@@ -1400,7 +1401,7 @@ protected
         if pkt[7] == "\x68"
           chan_user_id = pkt[8..9].unpack('S>')[0]
           chan_id = pkt[10..11].unpack('S>')[0]
-          flags = pkt[18..21].unpack('<L')[0]
+          flags = pkt[18..21].unpack('L<')[0]
           data = pkt[22..pkt.length]
           rdp_on_channel_receive(pkt, chan_user_id, chan_id, flags, data)
         end
