@@ -103,7 +103,7 @@ module Msf
 
         disconnect() if global
 
-        s = super(global)
+        s = super(global, {'SSL' => false})
         self.sock = s if global
 
         # Disable direct SMB when SMBDirect has not been set
@@ -149,6 +149,32 @@ module Msf
       # @param simple_client [Rex::Proto::SMB::SimpleClient] Optional SimpleClient instance to use
       # @return [void]
       def smb_login(simple_client = self.simple)
+        # Override the default RubySMB capabilities with Kerberos authentication
+        if datastore['SMB::Auth'] == Msf::Exploit::Remote::AuthOption::KERBEROS
+          fail_with(Msf::Exploit::Failure::BadConfig, 'The Smb::Rhostname option is required when using Kerberos authentication.') if datastore['Smb::Rhostname'].blank?
+          fail_with(Msf::Exploit::Failure::BadConfig, 'The SMBDomain option is required when using Kerberos authentication.') if datastore['SMBDomain'].blank?
+          fail_with(Msf::Exploit::Failure::BadConfig, 'The DomainControllerRhost is required when using Kerberos authentication.') if datastore['DomainControllerRhost'].blank?
+          offered_etypes = Msf::Exploit::Remote::AuthOption.as_default_offered_etypes(datastore['Smb::KrbOfferedEncryptionTypes'])
+          fail_with(Msf::Exploit::Failure::BadConfig, 'At least one encryption type is required when using Kerberos authentication.') if offered_etypes.empty?
+
+          kerberos_authenticator = Msf::Exploit::Remote::Kerberos::ServiceAuthenticator::SMB.new(
+            host: datastore['DomainControllerRhost'],
+            hostname: datastore['Smb::Rhostname'],
+            proxies: datastore['Proxies'],
+            realm: datastore['SMBDomain'],
+            username: datastore['SMBUser'],
+            password: datastore['SMBPass'],
+            framework: framework,
+            framework_module: self,
+            cache_file: datastore['Smb::Krb5Ccname'].blank? ? nil : datastore['Smb::Krb5Ccname'],
+            ticket_storage: kerberos_ticket_storage,
+            offered_etypes: offered_etypes
+          )
+
+          simple_client.client.extend(Msf::Exploit::Remote::SMB::Client::KerberosAuthentication)
+          simple_client.client.kerberos_authenticator = kerberos_authenticator
+        end
+
         simple_client.login(
           datastore['SMBName'],
           datastore['SMBUser'],
