@@ -5,8 +5,8 @@ module Msf
     module Windows
       module Accounts
         include Msf::Post::Windows::Error
+        include Msf::Post::Windows::ExtAPI
         include Msf::Post::Windows::Registry
-        require 'rex/post/meterpreter/extensions/extapi/command_ids'
 
         GUID = [
           ['Data1', :DWORD],
@@ -604,7 +604,7 @@ module Msf
           result = client.railgun.netapi32.NetGroupGetUsers(server_name, groupname, 0, 4, 4096, 4, 4, 0)
           if (result['return'] == 0) && ((result['totalentries'] % 4294967296) != 0)
             begin
-              members_info_addr = result['bufptr'].unpack1('V')
+              members_info_addr = result['bufptr']
               unless members_info_addr == 0
                 # Railgun assumes PDWORDS are pointers and returns 8 bytes for x64 architectures.
                 # Therefore we need to truncate the result value to an actual
@@ -641,7 +641,7 @@ module Msf
           result = client.railgun.netapi32.NetLocalGroupGetMembers(server_name, localgroupname, 3, 4, 4096, 4, 4, 0)
           if (result['return'] == 0) && ((result['totalentries'] % 4294967296) != 0)
             begin
-              members_info_addr = result['bufptr'].unpack1('V')
+              members_info_addr = result['bufptr']
               unless members_info_addr == 0
                 members_info = session.railgun.util.read_array(LOCALGROUP_MEMBERS_INFO, (result['totalentries'] % 4294967296), members_info_addr)
                 for member in members_info
@@ -675,7 +675,7 @@ module Msf
           result = client.railgun.netapi32.NetUserEnum(server_name, 0, client.railgun.const(filter), 4, 4096, 4, 4, 0)
           if (result['return'] == 0) && ((result['totalentries'] % 4294967296) != 0)
             begin
-              user_info_addr = result['bufptr'].unpack1('V')
+              user_info_addr = result['bufptr']
               unless user_info_addr == 0
                 user_info = session.railgun.util.read_array(USER_INFO, (result['totalentries'] % 4294967296), user_info_addr)
                 for member in user_info
@@ -708,7 +708,7 @@ module Msf
           result = client.railgun.netapi32.NetLocalGroupEnum(server_name, 0, 4, 4096, 4, 4, 0)
           if (result['return'] == 0) && ((result['totalentries'] % 4294967296) != 0)
             begin
-              localgroup_info_addr = result['bufptr'].unpack1('V')
+              localgroup_info_addr = result['bufptr']
               unless localgroup_info_addr == 0
                 localgroup_info = session.railgun.util.read_array(LOCALGROUP_INFO, (result['totalentries'] % 4294967296), localgroup_info_addr)
                 for member in localgroup_info
@@ -741,7 +741,7 @@ module Msf
           result = client.railgun.netapi32.NetGroupEnum(server_name, 0, 4, 4096, 4, 4, 0)
           if (result['return'] == 0) && ((result['totalentries'] % 4294967296) != 0)
             begin
-              group_info_addr = result['bufptr'].unpack1('V')
+              group_info_addr = result['bufptr']
               unless group_info_addr == 0
                 group_info = session.railgun.util.read_array(GROUP_INFO, (result['totalentries'] % 4294967296), group_info_addr)
                 for member in group_info
