@@ -16,7 +16,9 @@ class Db
 
   include Msf::Ui::Console::CommandDispatcher
   include Msf::Ui::Console::CommandDispatcher::Common
-  include Msf::Ui::Console::CommandDispatcher::Analyze
+  include Msf::Ui::Console::CommandDispatcher::Db::Common
+  include Msf::Ui::Console::CommandDispatcher::Db::Analyze
+  include Msf::Ui::Console::CommandDispatcher::Db::Klist
 
   DB_CONFIG_PATH = 'framework/database'
 
@@ -46,6 +48,7 @@ class Db
       "vulns"         => "List all vulnerabilities in the database",
       "notes"         => "List all notes in the database",
       "loot"          => "List all loot in the database",
+      "klist"         => "List Kerberos tickets in the database",
       "db_import"     => "Import a scan result file (filetype will be auto-detected)",
       "db_export"     => "Export a file containing the contents of the database",
       "db_nmap"       => "Executes nmap and records the output automatically",
@@ -86,21 +89,6 @@ class Db
     end
   end
 
-  #
-  # Returns true if the db is connected, prints an error and returns
-  # false if not.
-  #
-  # All commands that require an active database should call this before
-  # doing anything.
-  #
-  def active?
-    if not framework.db.active
-      print_error("Database not connected")
-      return false
-    end
-    true
-  end
-
   @@workspace_opts = Rex::Parser::Arguments.new(
     [ '-h', '--help' ] => [ false, 'Help banner.'],
     [ '-a', '--add' ] => [ true, 'Add a workspace.', '<name>'],
@@ -394,9 +382,13 @@ class Db
     opts[:workspace] = framework.db.workspace
     opts[:tag_name] = tag_name
 
+    # This will be the case if no IP was passed in, and we are just trying to delete all
+    # instances of a given tag within the database.
     if rws == [nil]
-      unless framework.db.delete_host_tag(opts)
-        print_error("Host #{opts[:address].to_s + " " if opts[:address]}could not be found.")
+      wspace = Msf::Util::DBManager.process_opts_workspace(opts, framework)
+      wspace.hosts.each do |host|
+        opts[:address] = host.address
+        framework.db.delete_host_tag(opts)
       end
     else
       rws.each do |rw|
@@ -408,7 +400,6 @@ class Db
         end
       end
     end
-
   end
 
   @@hosts_columns = [ 'address', 'mac', 'name', 'os_name', 'os_flavor', 'os_sp', 'purpose', 'info', 'comments']
@@ -507,6 +498,7 @@ class Db
         onlyup = true
       when '-o'
         output = val
+        output = ::File.expand_path(output)
       when '-R', '--rhosts'
         set_rhosts = true
       when '-S', '--search'
@@ -694,6 +686,8 @@ class Db
       return @@services_columns
     when '-O', '--order'
       return []
+    when '-o', '--output'
+      return tab_complete_filenames(str, words)
     when '-p', '--port'
       return []
     when '-r', '--protocol'
@@ -923,6 +917,10 @@ class Db
     if words.length == 1
       return @@vulns_opts.option_keys.select { |opt| opt.start_with?(str) }
     end
+    case words[-1]
+    when '-o', '--output'
+      return tab_complete_filenames(str, words)
+    end
   end
 
   def cmd_vulns_help
@@ -1097,6 +1095,8 @@ class Db
     case words[-1]
     when '-O', '--order'
       return []
+    when '-o', '--output'
+      return tab_complete_filenames(str, words)
     end
 
     []
@@ -1166,6 +1166,7 @@ class Db
         search_term = val
       when '-o', '--output'
         output_file = val
+        output_file = ::File.expand_path(output_file)
       when '-O'
         if (order_by = val.to_i - 1) < 0
           print_error('Please specify a column number starting from 1')
@@ -2131,48 +2132,6 @@ class Db
     true
   end
 
-
-  #
-  # Miscellaneous option helpers
-  #
-
-  #
-  # Takes +host_ranges+, an Array of RangeWalkers, and chunks it up into
-  # blocks of 1024.
-  #
-  def each_host_range_chunk(host_ranges, &block)
-    # Chunk it up and do the query in batches. The naive implementation
-    # uses so much memory for a /8 that it's basically unusable (1.6
-    # billion IP addresses take a rather long time to allocate).
-    # Chunking has roughly the same performance for small batches, so
-    # don't worry about it too much.
-    host_ranges.each do |range|
-      if range.nil? or range.length.nil?
-        chunk = nil
-        end_of_range = true
-      else
-        chunk = []
-        end_of_range = false
-        # Set up this chunk of hosts to search for
-        while chunk.length < 1024 and chunk.length < range.length
-          n = range.next_ip
-          if n.nil?
-            end_of_range = true
-            break
-          end
-          chunk << n
-        end
-      end
-
-      # The block will do some
-      yield chunk
-
-      # Restart the loop with the same RangeWalker if we didn't get
-      # to the end of it in this chunk.
-      redo unless end_of_range
-    end
-  end
-
   #######
   private
 
