@@ -21,6 +21,7 @@ class Msf::Ui::Console::CommandDispatcher::Developer
 
   def initialize(driver)
     super
+    @modified_files = modified_file_paths(print_errors: false)
   end
 
   def name
@@ -77,24 +78,21 @@ class Msf::Ui::Console::CommandDispatcher::Developer
     load full_path
   end
 
-  def reload_changed_files
-    # Using an array avoids shelling out, so we avoid escaping/quoting
-    changed_files = %w[git diff --name-only]
+  # @return [Array<String>] The list of modified file paths since startup
+  def modified_file_paths(print_errors: true)
+    files, is_success = modified_files
 
-    output, status = Open3.capture2e(*changed_files, chdir: Msf::Config.install_root)
-
-    unless status.success?
-      print_error("Git is not available: #{output.chomp}")
-      return
+    unless is_success
+      print_error("Git is not available") if print_errors
+      files = []
     end
 
-    files = output.split("\n")
-
-    files.each do |file|
+    @modified_files ||= []
+    @modified_files |= files.map do |file|
       next if file.end_with?('_spec.rb') || file.end_with?("spec_helper.rb")
-      f = File.join(Msf::Config.install_root, file)
-      reload_file(f, print_errors: false)
-    end
+      File.join(Msf::Config.install_root, file)
+    end.compact
+    @modified_files
   end
 
   def cmd_irb_help
@@ -202,6 +200,7 @@ class Msf::Ui::Console::CommandDispatcher::Developer
     print_line 'Usage: edit [file/to/edit]'
     print_line
     print_line "Edit the currently active module or a local file with #{local_editor}."
+    print_line 'To change the preferred editor, you can "setg LocalEditor".'
     print_line 'If a library file is specified, it will automatically be reloaded after editing.'
     print_line 'Otherwise, you can reload the active module with "reload" or "rerun".'
     print_line
@@ -262,6 +261,7 @@ class Msf::Ui::Console::CommandDispatcher::Developer
   # Reload Ruby library files from specified paths
   #
   def cmd_reload_lib(*args)
+    files = []
     options = OptionParser.new do |opts|
       opts.banner = 'Usage: reload_lib lib/to/reload.rb [...]'
       opts.separator ''
@@ -274,16 +274,21 @@ class Msf::Ui::Console::CommandDispatcher::Developer
 
       opts.on '-a', '--all', 'Reload all* changed files in your current Git working tree.
                                      *Excludes modules and non-Ruby files.' do
-        return reload_changed_files
+        files.concat(modified_file_paths)
       end
     end
 
     # The remaining unparsed arguments are files
-    files = options.order(args)
+    files.concat(options.order(args))
+    files.uniq!
 
     return print(options.help) if files.empty?
 
-    files.each { |file| reload_file(file) }
+    files.each do |file|
+      reload_file(file)
+    rescue ScriptError, StandardError => e
+      print_error("Error while reloading file #{file.inspect}: #{e}:\n#{e.backtrace.to_a.map { |line| "  #{line}" }.join("\n")}")
+    end
   end
 
   #
@@ -297,6 +302,7 @@ class Msf::Ui::Console::CommandDispatcher::Developer
     print_line 'Usage: log'
     print_line
     print_line 'Display framework.log paged to the end if possible.'
+    print_line 'To change the preferred pager, you can "setg LocalPager".'
     print_line 'For full effect, "setg LogLevel 3" before running modules.'
     print_line
     print_line "Log location: #{File.join(Msf::Config.log_directory, 'framework.log')}"
@@ -399,7 +405,7 @@ class Msf::Ui::Console::CommandDispatcher::Developer
 
     begin
       start_time = Process.clock_gettime(Process::CLOCK_MONOTONIC)
-      command = args.join(' ')
+      command = Shellwords.shelljoin(args)
 
       case profiler
       when '--cpu'
@@ -435,4 +441,21 @@ class Msf::Ui::Console::CommandDispatcher::Developer
     print @@time_opts.usage
     print_line
   end
+
+  private
+
+  def modified_files
+    # Using an array avoids shelling out, so we avoid escaping/quoting
+    changed_files = %w[git diff --name-only]
+    begin
+      output, status = Open3.capture2e(*changed_files, chdir: Msf::Config.install_root)
+      is_success = status.success?
+      output = output.split("\n")
+    rescue => e
+      elog(e)
+      output = []
+      is_success = false
+    end
+    return output, is_success
+  end
 end
