@@ -269,64 +269,9 @@ class Exploit
   alias cmd_rerun_help cmd_rexploit_help
 
   # Select a reasonable default payload and minimally configure it
-  # TODO: Move this somewhere better or make it more dynamic?
   # @param [Msf::Module] mod
   def self.choose_payload(mod)
-    compatible_payloads = mod.compatible_payloads(
-      excluded_platforms: ['Multi'] # We don't want to select a multi payload
-    ).map(&:first)
-
-    # XXX: Determine LHOST based on RHOST or an arbitrary internet address
-    lhost = Rex::Socket.source_address(mod.datastore['RHOST'] || '50.50.50.50')
-
-    configure_payload = lambda do |payload|
-      if mod.datastore.is_a?(Msf::DataStoreWithFallbacks)
-        payload_defaults = { 'PAYLOAD' => payload }
-
-        # Set LHOST if this is a reverse payload
-        if payload.index('reverse')
-          payload_defaults['LHOST'] = lhost
-        end
-        mod.datastore.import_defaults_from_hash(payload_defaults, imported_by: 'choose_payload')
-      else
-        mod.datastore['PAYLOAD'] = payload
-        # Set LHOST if this is a reverse payload
-        if payload.index('reverse')
-          mod.datastore['LHOST'] = lhost
-        end
-      end
-
-      payload
-    end
-
-    # If there is only one compatible payload, return it immediately
-    if compatible_payloads.length == 1
-      return configure_payload.call(compatible_payloads.first)
-    end
-
-    # XXX: This approach is subpar, and payloads should really be ranked!
-    preferred_payloads = [
-      # These payloads are generally reliable and common enough in practice
-      '/meterpreter/reverse_tcp',
-      '/shell/reverse_tcp',
-      'cmd/unix/reverse_bash',
-      'cmd/unix/reverse_netcat',
-      'cmd/windows/powershell_reverse_tcp',
-      # Fall back on a generic payload to autoselect a specific payload
-      'generic/shell_reverse_tcp',
-      'generic/shell_bind_tcp'
-    ]
-
-    # XXX: This is not efficient in the slightest
-    preferred_payloads.each do |type|
-      payload = compatible_payloads.find { |name| name.end_with?(type) }
-
-      next unless payload
-
-      return configure_payload.call(payload)
-    end
-
-    nil
+    Msf::Payload.choose_payload(mod)
   end
 
 end
