@@ -29,7 +29,12 @@ module Msf
           @@favorite_opts = Rex::Parser::Arguments.new(
             '-h' => [false, 'Help banner'],
             '-c' => [false, 'Clear the contents of the favorite modules file'],
-            '-d' => [false, 'Delete module(s) or the current active module from the favorite modules file']
+            '-d' => [false, 'Delete module(s) or the current active module from the favorite modules file'],
+            '-l' => [false, 'Print the list of favorite modules (alias for `show favorites`)']
+          )
+
+          @@favorites_opts = Rex::Parser::Arguments.new(
+            '-h' => [false, 'Help banner']
           )
 
           def commands
@@ -49,6 +54,7 @@ module Msf
               "show"       => "Displays modules of a given type, or all modules",
               "use"        => "Interact with a module by name or search term/index",
               "favorite"   => "Add module(s) to the list of favorite modules",
+              "favorites"  => "Print the list of favorite modules (alias for `show favorites`)"
             }
           end
 
@@ -127,6 +133,7 @@ module Msf
               end
             else
               print(Serializer::ReadableText.dump_module(mod))
+              print("\nView the full module info with the #{Msf::Ui::Tip.highlight('info -d')} command.\n\n")
             end
           end
 
@@ -727,7 +734,7 @@ module Msf
                 end
                 unless mod_resolved
                   elog("Module #{mod_name} not found, and no loading errors found. If you're using a custom module" \
-                    ' refer to our wiki: https://github.com/rapid7/metasploit-framework/wiki/Running-Private-Modules')
+                    ' refer to our wiki: https://docs.metasploit.com/docs/using-metasploit/intermediate/running-private-modules.html')
 
                   # Avoid trying to use the search result if it exactly matches
                   # the module we were trying to load. The module cannot be
@@ -1155,7 +1162,7 @@ module Msf
             readable = false
             contents = ''
 
-            if File.exists?(favs_file)
+            if File.exist?(favs_file)
               exists = true
             end
 
@@ -1175,10 +1182,11 @@ module Msf
           # Add modules to or delete modules from the fav_modules file
           #
           def cmd_favorite(*args)
+            valid_custom_args = ['-c', '-d', '-l']
             favs_file = Msf::Config.fav_modules_file
 
             # always display the help banner if -h is provided or if multiple options are provided
-            if args.include?('-h') || (args.include?('-c') && args.include?('-d'))
+            if args.include?('-h') || args.select{ |arg| arg if valid_custom_args.include?(arg) }.length > 1
               cmd_favorite_help
               return
             end
@@ -1219,6 +1227,14 @@ module Msf
               end
 
               favorite_del(args, false, favs_file)
+            when '-l'
+              args.delete('-l')
+              unless args.empty?
+                print_error('Option `-l` does not support arguments.')
+                cmd_favorite_help
+                return
+              end
+              cmd_show('favorites')
             else # no valid options, but there are arguments
               if args[0].start_with?('-')
                 print_error('Invalid option provided')
@@ -1230,6 +1246,30 @@ module Msf
             end
           end
 
+          def cmd_favorites_help
+            print_line 'Usage: favorites'
+            print_line
+            print_line 'Print the list of favorite modules (alias for `show favorites`)'
+            print @@favorites_opts.usage
+          end
+
+          #
+          # Print the list of favorite modules from the fav_modules file (alias for `show favorites`)
+          #
+          def cmd_favorites(*args)
+            if args.empty?
+              cmd_show('favorites')
+              return
+            end
+
+            # always display the help banner if the command is called with arguments
+            unless args.include?('-h')
+              print_error('Invalid option(s) provided')
+            end
+
+            cmd_favorites_help
+          end
+
           #
           # Tab complete module names
           #
@@ -1379,7 +1419,7 @@ module Msf
           def show_favorites # :nodoc:
             favs_file = Msf::Config.fav_modules_file
 
-            unless File.exists?(favs_file)
+            unless File.exist?(favs_file)
               print_error("The favorite modules file does not exist")
               return
             end
@@ -1455,11 +1495,11 @@ module Msf
           def show_targets(mod) # :nodoc:
             case mod
             when Msf::Exploit
-              mod_targs = Serializer::ReadableText.dump_exploit_targets(mod, '   ')
-              print("\nExploit targets:\n\n#{mod_targs}\n") if (mod_targs and mod_targs.length > 0)
+              mod_targs = Serializer::ReadableText.dump_exploit_targets(mod, '', "\nExploit targets:")
+              print("#{mod_targs}\n") if (mod_targs and mod_targs.length > 0)
             when Msf::Evasion
-              mod_targs = Serializer::ReadableText.dump_evasion_targets(mod, '   ')
-              print("\nEvasion targets:\n\n#{mod_targs}\n") if (mod_targs and mod_targs.length > 0)
+              mod_targs = Serializer::ReadableText.dump_evasion_targets(mod, '', "\nEvasion targets:")
+              print("#{mod_targs}\n") if (mod_targs and mod_targs.length > 0)
             end
           end
 
@@ -1489,6 +1529,7 @@ module Msf
                 print("\nPayload advanced options (#{mod.datastore['PAYLOAD']}):\n\n#{p_opt}\n") if (p_opt and p_opt.length > 0)
               end
             end
+            print("\nView the full module info with the #{Msf::Ui::Tip.highlight('info')}, or #{Msf::Ui::Tip.highlight('info -d')} command.\n\n")
           end
 
           def show_evasion_options(mod) # :nodoc:
