@@ -10,10 +10,10 @@ module Msf
         #
         # Tab completion for datastore names
         #
-        # @param [Msf::DataStore] datastore
-        # @param str [String] the string currently being typed before tab was hit
-        # @param words [Array<String>] the previously completed words on the command
-        #   line. `words` is always at least 1 when tab completion has reached this
+        # @param datastore [Msf::DataStore]
+        # @param _str [String] the string currently being typed before tab was hit
+        # @param _words [Array<String>] the previously completed words on the command
+        #   line. `_words` is always at least 1 when tab completion has reached this
         #   stage since the command itself has been completed.
         def tab_complete_datastore_names(datastore, _str, _words)
           keys = (
@@ -28,14 +28,14 @@ module Msf
         #
         # Tab completion for a module's datastore names
         #
-        # @param [Msf::Module] mod
+        # @param mod [Msf::Module]
         # @param str [String] the string currently being typed before tab was hit
         # @param words [Array<String>] the previously completed words on the command
         #   line. `words` is always at least 1 when tab completion has reached this
         #   stage since the command itself has been completed.
-        def tab_complete_module_datastore_names(mod, _str, _words)
+        def tab_complete_module_datastore_names(mod, str, words)
           datastore = mod ? mod.datastore : framework.datastore
-          keys = tab_complete_datastore_names(datastore, _str, _words)
+          keys = tab_complete_datastore_names(datastore, str, words)
 
           if mod
             keys = keys.delete_if do |name|
@@ -80,8 +80,6 @@ module Msf
 
           mod.options.sorted.each do |e|
             name, _opt = e
-            next unless Msf::OptCondition.show_option(mod, _opt)
-
             res << name
           end
           # Exploits provide these three default options
