@@ -20,8 +20,10 @@ class Client
 
   #
   # Creates a new client instance
+  # @param http_trace_proc_request [Proc] A proc object passed to log HTTP requests if HTTP-Trace is set
+  # @param http_trace_proc_response [Proc] A proc object passed to log HTTP responses if HTTP-Trace is set
   #
-  def initialize(host, port = 80, context = {}, ssl = nil, ssl_version = nil, proxies = nil, username = '', password = '', comm: nil)
+  def initialize(host, port = 80, context = {}, ssl = nil, ssl_version = nil, proxies = nil, username = '', password = '', kerberos_authenticator: nil, comm: nil, subscriber: nil)
     self.hostname = host
     self.port     = port.to_i
     self.context  = context
@@ -30,8 +32,10 @@ class Client
     self.proxies  = proxies
     self.username = username
     self.password = password
+    self.kerberos_authenticator = kerberos_authenticator
     self.comm = comm
-
+    self.subscriber = subscriber || HttpSubscriber.new
+    
     # Take ClientRequest's defaults, but override with our own
     self.config = Http::ClientRequest::DefaultConfig.merge({
       'read_max_data'   => (1024*1024*1),
@@ -228,18 +232,24 @@ class Client
   # @return (see #read_response)
   def _send_recv(req, t = -1, persist = false)
     @pipeline = persist
+    subscriber.on_request(req)
     if req.respond_to?(:opts) && req.opts['ntlm_transform_request'] && self.ntlm_client
       req = req.opts['ntlm_transform_request'].call(self.ntlm_client, req)
+    elsif req.respond_to?(:opts) && req.opts['krb_transform_request'] && self.krb_encryptor
+      req = req.opts['krb_transform_request'].call(self.krb_encryptor, req)
     end
-
+    
     send_request(req, t)
 
-    res = read_response(t)
+    res = read_response(t, :original_request => req)
     if req.respond_to?(:opts) && req.opts['ntlm_transform_response'] && self.ntlm_client
       req.opts['ntlm_transform_response'].call(self.ntlm_client, res)
+    elsif req.respond_to?(:opts) && req.opts['krb_transform_response'] && self.krb_encryptor
+      req = req.opts['krb_transform_response'].call(self.krb_encryptor, res)
     end
     res.request = req.to_s if res
     res.peerinfo = peerinfo if res
+    subscriber.on_response(res)
     res
   end
 
@@ -276,7 +286,11 @@ class Client
       end
     end
 
-    return res if opts['username'].nil? or opts['username'] == ''
+    if opts[:kerberos_authenticator].nil?
+      opts[:kerberos_authenticator] = self.kerberos_authenticator
+    end
+
+    return res if (opts['username'].nil? or opts['username'] == '') and opts[:kerberos_authenticator].nil?
     supported_auths = res.headers['WWW-Authenticate']
 
     # if several providers are available, the client may want one in particular
@@ -308,6 +322,13 @@ class Client
         res = temp_response
       end
       return res
+    elsif supported_auths.include?('Negotiate') && (preferred_auth.nil? || preferred_auth == 'Kerberos')
+      opts['provider'] = 'Negotiate'
+      temp_response = kerberos_auth(opts)
+      if temp_response.kind_of? Rex::Proto::Http::Response
+        res = temp_response
+      end
+      return res
     end
     return res
   end
@@ -464,6 +485,53 @@ class Client
     end
   end
 
+  def kerberos_auth(opts={})
+    to = opts['timeout'] || 20
+    auth_result = self.kerberos_authenticator.authenticate(mechanism: Rex::Proto::Gss::Mechanism::KERBEROS)
+    gss_data = auth_result[:security_blob]
+    gss_data_b64 = Rex::Text.encode_base64(gss_data)
+
+    # Separate options for the auth requests
+    auth_opts = opts.clone
+    auth_opts['headers'] = opts['headers'].clone
+    auth_opts['headers']['Authorization'] = "Kerberos #{gss_data_b64}"
+
+    if auth_opts['no_body_for_auth']
+      auth_opts.delete('data')
+      auth_opts.delete('krb_transform_request')
+      auth_opts.delete('krb_transform_response')
+    end
+
+    begin
+      # Send the auth request
+      r = request_cgi(auth_opts)
+      resp = _send_recv(r, to)
+      unless resp.kind_of? Rex::Proto::Http::Response
+        return nil
+      end
+
+      # Get the challenge and craft the response
+      response = resp.headers['WWW-Authenticate'].scan(/Kerberos ([A-Z0-9\x2b\x2f=]+)/ni).flatten[0]
+      return resp unless response
+
+      decoded = Rex::Text.decode_base64(response)
+      mutual_auth_result = self.kerberos_authenticator.parse_gss_init_response(decoded, auth_result[:session_key], mechanism: 'kerberos')
+      self.krb_encryptor = self.kerberos_authenticator.get_message_encryptor(mutual_auth_result[:ap_rep_subkey], 
+                                                                                  auth_result[:client_sequence_number],
+                                                                                  mutual_auth_result[:server_sequence_number])
+
+      if opts['no_body_for_auth']
+        # If the body wasn't sent in the authentication, now do the actual request
+        r = request_cgi(opts)
+        resp = _send_recv(r, to, true)
+      end
+      return resp
+
+    rescue ::Errno::EPIPE, ::Timeout::Error
+      return nil
+    end
+  end
+
   #
   # Builds a series of requests to complete Negotiate Auth. Works essentially
   # the same way as Digest auth. Same pipelining concerns exist.
@@ -568,6 +636,12 @@ class Client
     resp = Response.new
     resp.max_data = config['read_max_data']
 
+    original_request = opts.fetch(:original_request) { nil }
+    parse_opts = {}
+    unless original_request.nil?
+      parse_opts = { :orig_method => original_request.opts['method'] }
+    end
+
     Timeout.timeout((t < 0) ? nil : t) do
 
       rv = nil
@@ -580,7 +654,7 @@ class Client
         begin
 
           buff = conn.get_once(resp.max_data, 1)
-          rv   = resp.parse(buff || '')
+          rv   = resp.parse(buff || '', parse_opts)
 
         # Handle unexpected disconnects
         rescue ::Errno::EPIPE, ::EOFError, ::IOError
@@ -629,7 +703,7 @@ class Client
         body = resp.body
         resp = Response.new
         resp.max_data = config['read_max_data']
-        rv = resp.parse(body)
+        rv = resp.parse(body, parse_opts)
       # We found a 100 Continue but didn't read the real reply yet
       # Otherwise reread the reply, but don't try this hack again
       else
@@ -679,7 +753,7 @@ class Client
     end
     nil
   end
-
+  
   #
   # An optional comm to use for creating the underlying socket.
   #
@@ -718,11 +792,14 @@ class Client
   attr_accessor :proxies
 
   # Auth
-  attr_accessor :username, :password
+  attr_accessor :username, :password, :kerberos_authenticator
 
   # When parsing the request, thunk off the first response from the server, since junk
   attr_accessor :junk_pipeline
 
+  # @return [Rex::Proto::Http::HttpSubscriber] The HTTP subscriber
+  attr_accessor :subscriber
+
 protected
 
   # https
@@ -734,6 +811,11 @@ protected
   # The established NTLM connection info
   #
   attr_accessor :ntlm_client
+
+  #
+  # The established kerberos connection info
+  #
+  attr_accessor :krb_encryptor
 end
 
 end
