@@ -1,11 +1,11 @@
 # -*- coding: binary -*-
 
 module Rex::Proto::Thrift
-  class DataType < BinData::Uint8
+  class ThriftDataType < BinData::Uint8
     T_STOP = 0
     T_UTF7 = 11
 
-    default_parameter assert: -> { !DataType.name(value).nil? }
+    default_parameter assert: -> { !ThriftDataType.name(value).nil? }
 
     def self.name(value)
       constants.select { |c| c.upcase == c }.find { |c| const_get(c) == value }
@@ -16,7 +16,7 @@ module Rex::Proto::Thrift
     end
   end
 
-  class MessageType < BinData::Uint16be
+  class ThriftMessageType < BinData::Uint16be
     CALL = 1
     REPLY = 2
 
@@ -31,8 +31,9 @@ module Rex::Proto::Thrift
     end
   end
 
-  class Header < BinData::Record
+  class ThriftHeader < BinData::Record
     endian :big
+    search_prefix :thrift
 
     uint16       :version, initial_value: 0x8001
     message_type :message_type
@@ -41,14 +42,15 @@ module Rex::Proto::Thrift
     uint32       :sequence_id
   end
 
-  class Data < BinData::Record
+  class ThriftData < BinData::Record
     endian :big
+    search_prefix :thrift
 
-    data_type :data_type, initial_value: DataType::T_STOP
-    uint16    :field_id, onlyif: -> { data_type != DataType::T_STOP }
-    uint32    :data_length, onlyif: -> { data_type != DataType::T_STOP }, value: -> { data_value.length }
-    choice    :data_value, onlyif: -> { data_type != DataType::T_STOP }, selection: :data_type do
-      string DataType::T_UTF7
+    data_type :data_type, initial_value: ThriftDataType::T_STOP
+    uint16    :field_id, onlyif: -> { data_type != ThriftDataType::T_STOP }
+    uint32    :data_length, onlyif: -> { data_type != ThriftDataType::T_STOP }, value: -> { data_value.length }
+    choice    :data_value, onlyif: -> { data_type != ThriftDataType::T_STOP }, selection: :data_type do
+      string ThriftDataType::T_UTF7
     end
   end
 end
