@@ -8,23 +8,27 @@ class MetasploitModule < Msf::Post
   include Msf::Auxiliary::Report
 
   def initialize(info = {})
-    super(update_info(info,
-      'Name'          => 'Multi Recon Local Exploit Suggester',
-      'Description'   => %q{
-        This module suggests local meterpreter exploits that can be used.
+    super(
+      update_info(
+        info,
+        'Name' => 'Multi Recon Local Exploit Suggester',
+        'Description' => %q{
+          This module suggests local meterpreter exploits that can be used.
 
-        The exploits are suggested based on the architecture and platform
-        that the user has a shell opened as well as the available exploits
-        in meterpreter.
+          The exploits are suggested based on the architecture and platform
+          that the user has a shell opened as well as the available exploits
+          in meterpreter.
 
-        It's important to note that not all local exploits will be fired.
-        Exploits are chosen based on these conditions: session type,
-        platform, architecture, and required default options.
-      },
-      'License'       => MSF_LICENSE,
-      'Author'        => [ 'sinn3r', 'Mo' ],
-      'Platform'      => all_platforms,
-      'SessionTypes'  => [ 'meterpreter', 'shell' ]))
+          It's important to note that not all local exploits will be fired.
+          Exploits are chosen based on these conditions: session type,
+          platform, architecture, and required default options.
+        },
+        'License' => MSF_LICENSE,
+        'Author' => [ 'sinn3r', 'Mo' ],
+        'Platform' => all_platforms,
+        'SessionTypes' => [ 'meterpreter', 'shell' ]
+      )
+    )
     register_options [
       Msf::OptInt.new('SESSION', [ true, 'The session to run this module on' ]),
       Msf::OptBool.new('SHOWDESCRIPTION', [true, 'Displays a detailed description for the available exploits', false])
@@ -150,7 +154,7 @@ class MetasploitModule < Msf::Post
   end
 
   def verify_mod(mod)
-    return { has_check: false } unless mod.kind_of?(Msf::Exploit::Local) && mod.has_check?
+    return { has_check: false } unless mod.is_a?(Msf::Exploit::Local) && mod.has_check?
 
     result = {
       has_check: true,
@@ -197,7 +201,7 @@ class MetasploitModule < Msf::Post
       print_error 'No suggestions available.'
       vprint_line
       vprint_session_info
-      vprint_status unwanted_modules_table(@local_exploits.select { |mod| !is_module_wanted?(mod) })
+      vprint_status unwanted_modules_table(@local_exploits.reject { |mod| is_module_wanted?(mod) })
       return
     end
 
@@ -206,7 +210,7 @@ class MetasploitModule < Msf::Post
       print "%bld%blu[*]%clr Running check method for exploit #{index + 1} / #{runnable_exploits.count}\r"
       begin
         checkcode = mod[:module].check
-      rescue => e
+      rescue StandardError => e
         elog("#Local Exploit Suggester failed with: #{e.class} when using #{mod[:module].shortname}", error: e)
         vprint_error "Check with module #{mod[:module].fullname} failed with error #{e.class}"
         next { module: mod[:module], errors: ['The check raised an exception.'] }
@@ -242,16 +246,16 @@ class MetasploitModule < Msf::Post
 
     vprint_line
     vprint_session_info
-    vprint_status unwanted_modules_table(@local_exploits.select { |mod| !is_module_wanted?(mod) })
+    vprint_status unwanted_modules_table(@local_exploits.reject { |mod| is_module_wanted?(mod) })
 
     report_data = []
     results.each do |result|
       report_data << [result[:module].fullname, result[:checkcode]] if result[:checkcode]
     end
     report_note(
-      :host => session.session_host,
-      :type => 'local.suggested_exploits',
-      :data => report_data
+      host: session.session_host,
+      type: 'local.suggested_exploits',
+      data: report_data
     )
   end
 
@@ -345,7 +349,7 @@ class MetasploitModule < Msf::Post
         index + 1,
         mod[:module].fullname,
         mod[:result][:incompatibility_reasons].join('. '),
-        platforms.map { |module_platform| module_platform.realname }.sort.join(', '),
+        platforms.map(&:realname).sort.join(', '),
         arch.any? ? arch.sort.join(', ') : 'No defined architectures',
         mod[:module].session_types.any? ? mod[:module].session_types.sort.join(', ') : 'No defined session types'
       ]
@@ -386,15 +390,15 @@ class MetasploitModule < Msf::Post
     ].include? checkcode
   end
 
-  def print_status(msg='')
+  def print_status(msg = '')
     super(session ? "#{session.session_host} - #{msg}" : msg)
   end
 
-  def print_good(msg='')
+  def print_good(msg = '')
     super(session ? "#{session.session_host} - #{msg}" : msg)
   end
 
-  def print_error(msg='')
+  def print_error(msg = '')
     super(session ? "#{session.session_host} - #{msg}" : msg)
   end
 end
