@@ -33,10 +33,10 @@ class MetasploitModule < Msf::Post
 
   # Run Method for when run command is issued
   def run
-    print_status("Running module against #{sysinfo['Computer']}") if not sysinfo.nil?
-    domain = get_domain()
-    if not domain.empty?
-      hostname_list = get_domain_computers()
+    print_status("Running module against #{sysinfo['Computer']}") if !sysinfo.nil?
+    domain = get_domain
+    if !domain.empty?
+      hostname_list = get_domain_computers
       list_computers(domain, hostname_list)
     end
   end
@@ -46,20 +46,20 @@ class MetasploitModule < Msf::Post
     vprint_status("Looking up IP for #{hostname}")
     result = client.net.resolve.resolve_host(hostname)
 
-    return nil if result[:ip].nil? or result[:ip].blank?
+    return nil if result[:ip].nil? || result[:ip].blank?
 
     return result[:ip]
   end
 
   # List Members of a domain group
-  def get_domain_computers()
+  def get_domain_computers
     computer_list = []
     devisor = "-------------------------------------------------------------------------------\r\n"
     raw_list = cmd_exec('net view').split(devisor)[1]
     if raw_list =~ /The command completed successfully/
       raw_list.sub!(/The command completed successfully\./, '')
       raw_list.gsub!(/\\\\/, '')
-      raw_list.split(" ").each do |m|
+      raw_list.split(' ').each do |m|
         computer_list << m
       end
     end
@@ -68,29 +68,29 @@ class MetasploitModule < Msf::Post
   end
 
   # Gets the Domain Name
-  def get_domain()
-    domain = ""
+  def get_domain
+    domain = ''
     begin
-      subkey = "HKEY_LOCAL_MACHINE\\SOFTWARE\\Microsoft\\Windows\\CurrentVersion\\Group Policy\\History"
-      v_name = "DCName"
+      subkey = 'HKEY_LOCAL_MACHINE\\SOFTWARE\\Microsoft\\Windows\\CurrentVersion\\Group Policy\\History'
+      v_name = 'DCName'
       domain_dc = registry_getvaldata(subkey, v_name)
       dom_info = domain_dc.split('.')
       domain = dom_info[1].upcase
-    rescue
-      print_error("This host is not part of a domain.")
+    rescue StandardError
+      print_error('This host is not part of a domain.')
     end
     return domain
   end
 
   def list_computers(domain, hosts)
     tbl = Rex::Text::Table.new(
-      'Header' => "List of Domain Hosts for the primary Domain.",
+      'Header' => 'List of Domain Hosts for the primary Domain.',
       'Indent' => 1,
       'Columns' =>
       [
-        "Domain",
-        "Hostname",
-        "IPs",
+        'Domain',
+        'Hostname',
+        'IPs',
       ]
     )
     hosts.each do |hostname|
@@ -101,9 +101,9 @@ class MetasploitModule < Msf::Post
     print_line("\n" + results + "\n")
 
     report_note(
-      :host => session,
-      :type => 'domain.hosts',
-      :data => tbl.to_csv
+      host: session,
+      type: 'domain.hosts',
+      data: tbl.to_csv
     )
   end
 end
